.. _xpdu:

For XPD Users
*************

I will introduce how to use the software in an ipython or jupyter notebook session. I will first show the typical usage in the sections below.

.. toctree::
   :maxdepth: 2

   sb_overview
   sb_icollection
   usb_Beamtime
   usb_Experiment
   usb_Scan
   usb_Where
   usb_Running
   usb_QuickAssess
   usb_GlobalOptions
   db_export
   robot
   tomo


If you would like to know more about what happened behind, I recommend reading the sections below. I wrote about how the calibration, dark frame, mask and shutter are automatically controlled and how to tune their behavior using your own configuration.

.. toctree::
   :maxdepth: 2

   usb_design
   usb_calibration
   usb_darkframe
   usb_mask
   usb_shutter
